@@ -720,7 +720,8 @@ class CachedCTASQuery(CachedAthenaQuery):
         sql_paths: Optional[Union[str, List[str]]] = None,
         dynamodb_lock: Optional[bool] = True,
         logger: Optional[logging.Logger] = logging.getLogger(__name__),
-        expiry_seconds: Optional[int] = 0
+        expiry_seconds: Optional[int] = 0,
+        queue_queries: Optional[bool] = False
     ) -> None:
         if cache_path and not cache_path.startswith('s3://'):
             raise AssertionError(f"CTAS queries can only output to S3; current cache path: {cache_path}")
@@ -734,6 +735,7 @@ class CachedCTASQuery(CachedAthenaQuery):
             logger=logger,
             expiry_seconds=expiry_seconds
         )
+        self.queue_queries = queue_queries
         self.doggo = PandasDoggo()
 
     @classmethod
@@ -843,15 +845,17 @@ class CachedCTASQuery(CachedAthenaQuery):
             name="CTAS {}".format(output_file),
             output_location=self.cache_path
         )
-        self._ac.wait_for_completion()
 
-        # Drop the CTAS table
-        self._ac.add_query(
-            sql=f"DROP TABLE IF EXISTS {ctas_params['database']}.{ctas_params['table_name']}",
-            name="DROP CTAS {}".format(output_file),
-            output_location=self.cache_path
-        )
-        self._ac.wait_for_completion()
+        if not self.queue_queries:
+            self._ac.wait_for_completion()
+
+            # Drop the CTAS table
+            self._ac.add_query(
+                sql=f"DROP TABLE IF EXISTS {ctas_params['database']}.{ctas_params['table_name']}",
+                name="DROP CTAS {}".format(output_file),
+                output_location=self.cache_path
+            )
+            self._ac.wait_for_completion()
 
     @staticmethod
     def validate_ctas_params(
